@@ -1,5 +1,5 @@
 
-# $Id: RandomForest.R 2475 2006-02-23 15:11:21Z hothorn $
+# $Id: RandomForest.R 2538 2006-04-04 15:47:15Z hothorn $
 
 ### the fitting procedure
 cforestfit <- function(object, controls, weights = NULL, fitmem = NULL, 
@@ -117,7 +117,7 @@ RandomForest <- new("StatModel",
 
 ### the top-level convenience function
 cforest <- function(formula, data = list(), subset = NULL, weights = NULL, 
-                    controls = ctree_control(teststattype = "maxabs", 
+                    controls = ctree_control(teststat = "max", 
                                              testtype = "Teststatistic", 
                                              mincriterion = qnorm(0.9), mtry = 5, 
                                              savesplitstats = FALSE),
